==> haskell-statevar-1.1.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 StateVar
version:              1.1.1.1
visibility:           public
id:                   StateVar-1.1.1.1-L09KIp33uUYEpD2XQSjrks
key:                  StateVar-1.1.1.1-L09KIp33uUYEpD2XQSjrks
license:              BSD-3-Clause
copyright:
    Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne

maintainer:           Sven Panne <svenpanne@gmail.com>
author:               Sven Panne and Edward Kmett
homepage:             https://github.com/haskell-opengl/StateVar
synopsis:             State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.

category:             Data
abi:                  b772ab6abc54fa895a8f3f869e166a3a
exposed:              True
exposed-modules:      Data.StateVar
import-dirs:          /usr/lib/ghc-8.8.1/site-local/StateVar-1.1.1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/StateVar-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/StateVar-1.1.1.1
hs-libraries:         HSStateVar-1.1.1.1-L09KIp33uUYEpD2XQSjrks
depends:              base-4.13.0.0 stm-2.5.0.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html:         /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statevar-1.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 StateVar
version:              1.2
visibility:           public
id:                   StateVar-1.2-9GFTup1qqdWAy26rtsnB7R
key:                  StateVar-1.2-9GFTup1qqdWAy26rtsnB7R
license:              BSD-3-Clause
copyright:
    Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne

maintainer:           Sven Panne <svenpanne@gmail.com>
author:               Sven Panne and Edward Kmett
homepage:             https://github.com/haskell-opengl/StateVar
synopsis:             State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.

category:             Data
abi:                  989c3941900afe13ef07c37c0c150d3e
exposed:              True
exposed-modules:      Data.StateVar
import-dirs:          /usr/lib/ghc-8.8.3/site-local/StateVar-1.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/StateVar-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/StateVar-1.2
hs-libraries:         HSStateVar-1.2-9GFTup1qqdWAy26rtsnB7R
depends:              base-4.13.0.0 stm-2.5.0.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html:         /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
